/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbplugin.mojo;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;

/**
 * account parameter for Maven and SQL Installer as well
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class DbAccount
{
	//-------------------------------------------------------------------------------------------------------------------
	// members
	//-------------------------------------------------------------------------------------------------------------------

	/**
	 * @parameter
	 */
	private String jdbcDriver;

	/**
	 * @parameter
	 */
	private String jdbcUrl;

	/**
	 * @parameter
	 */
	private String user;

	/**
	 * @parameter
	 */
	private String password;


	private Connection dbConnection;


	//-------------------------------------------------------------------------------------------------------------------
	// constructor
	//-------------------------------------------------------------------------------------------------------------------

	/**
	 * default constructor for Mojo
	 */
	public DbAccount()
	{

	}

	/**
	 * Constructor
	 *
	 * @param jdbcDriver
	 * @param jdbcUrl
	 * @param user
	 * @param password
	 */
	public DbAccount(String jdbcDriver, String jdbcUrl, String user, String password)
	{
		this.jdbcDriver = jdbcDriver;
		this.jdbcUrl = jdbcUrl;
		this.user = user;
		this.password = password;
	}


	//-------------------------------------------------------------------------------------------------------------------
	// methods
	//-------------------------------------------------------------------------------------------------------------------

	public String getJdbcDriver()
	{
		return jdbcDriver;
	}


	public String getJdbcUrl()
	{
		return jdbcUrl;
	}


	public String getUser()
	{
		return user;
	}


	public String getPassword()
	{
		return password;
	}


	public Connection getConnection() throws ClassNotFoundException, SQLException
	{
		if (this.dbConnection == null) {
			Class.forName(this.getJdbcDriver());
			this.dbConnection = DriverManager.getConnection(getJdbcUrl(), getUser(), getPassword());
		}
		return this.dbConnection;
	}


	public void closeConnectionQuietly()
	{
		if (dbConnection != null) {
			try {
				dbConnection.close();
			} catch (SQLException e) {
				throw new IllegalStateException(e);
			}
		}
	}
}
