/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbplugin.resource;

import com.celum.dbplugin.installer.SqlScript;
import com.celum.dbplugin.installer.SqlScriptsResource;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * does version-filtering based on version value in DB.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class DbVersionFilter extends VersionFilter
{
	//-------------------------------------------------------------------------------------------------------------------
	// members & constants
	//-------------------------------------------------------------------------------------------------------------------

	/** DB connection */
	private final Connection con;

	/** SQL determines the DB version */
	private final String versionSql;


	//-------------------------------------------------------------------------------------------------------------------
	// constructor & methods
	//-------------------------------------------------------------------------------------------------------------------


	/**
	 * Constructor
	 *
	 * @param decoratedResource
	 * @param con
	 * @param versionSql
	 */
	public DbVersionFilter(SqlScriptsResource decoratedResource, Connection con, String versionSql, String stepPattern)
	{
		super(decoratedResource, stepPattern);
		this.con = con;
		this.versionSql = versionSql;
	}


	final int getDbVersion()
	{
		try {
			if (versionSql == null || versionSql.isEmpty()) {
				return -1;
			}

			Statement stmnt = con.createStatement();
			ResultSet res = stmnt.executeQuery(versionSql);
			if (res.next()) {
				int version = res.getInt(1);
				return version;
			}

			return -1;
		} catch (SQLException e) {
			return -1;
		}
	}
}
