/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbplugin.resource;

import com.celum.dbplugin.installer.SqlScript;
import com.celum.dbplugin.installer.SqlScriptsResource;

import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * provide access to SQL scripts loaded directly in memory. This is useful
 * mostly for testing purpose when you could mock your scripts.
 *
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class MemoryResource extends SqlScriptsResource
{
	//-------------------------------------------------------------------------------------------------------------------
	// members
	//-------------------------------------------------------------------------------------------------------------------

	/** holds SQL Scripts */
	private final List<SqlScript> scripts;


	//-------------------------------------------------------------------------------------------------------------------
	// constructors & methods
	//-------------------------------------------------------------------------------------------------------------------

	/**
	 * Constructor
	 */
	public MemoryResource()
	{
		scripts = new LinkedList<SqlScript>();
	}


	/**
	 * Constructor
	 * @param scripts
	 */
	public MemoryResource(List<SqlScript> scripts)
	{
		this.scripts = scripts;
	}


	/**
	 * adds sql script into in-memory holder
	 *
	 * @param script
	 * @return
	 */
	public MemoryResource addSqlScript(SqlScript script)
	{
		this.scripts.add(script);
		return this;
	}


	/**
	 * returns SQL scripts hold by this resource
	 * @return
	 */
	@Override
	public Collection<SqlScript> getSortedScripts()
	{
		Collections.sort(scripts);
		return scripts;
	}
}
