/*****************************************************************************
 * Copyright 2012 celum Slovakia s r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************/
package com.celum.dbplugin.resource;

import com.celum.dbplugin.installer.FileSqlScript;
import com.celum.dbplugin.installer.SqlScript;
import com.celum.dbplugin.installer.SqlScriptsResource;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * @author Zdenko Vrabel (zdenko.vrabel@celum.com)
 */
public class SqlDirResource extends SqlScriptsResource
{
	/** points to directory where are SQL scripts */
	private final File dir;


	/**
	 * Constructor
	 * @param dir
	 */
	public SqlDirResource(File dir)
	{
		this.dir = dir;
	}


	/**
	 * reads all script files inside directory, sort them and return
	 * them as a collection of sql scripts
	 * @return
	 */
	@Override
	public Collection<SqlScript> getSortedScripts()
	{
		if (dir == null) {
			throw new IllegalStateException("Configuration error. Please define a scripts-directory for that goal in your pom.xml");
		}

		File[] sqlScripts = dir.listFiles();
		if (sqlScripts == null) {
			throw new IllegalStateException("non-existing or empty folder " + dir.toString());
		}

		List<SqlScript> out = new LinkedList<SqlScript>();
		for (int i = 0; i < sqlScripts.length; ++i) {
			if (sqlScripts[i].isFile()) {
				SqlScript script = new FileSqlScript(sqlScripts[i]);
				out.add(script);
			}
		}

		Collections.sort(out);
		return out;
	}
}
